diff --git a/../natb_CY48R1.0_default/arpifs/phys_ec/cloudsc.F90 b/arpifs/phys_ec/cloudsc.F90
index 5af32a887c..5860d74586 100644
--- a/../natb_CY48R1.0_default/arpifs/phys_ec/cloudsc.F90
+++ b/arpifs/phys_ec/cloudsc.F90
@@ -150,6 +150,14 @@ SUBROUTINE CLOUDSC &
 !        2020-12 : R.Forbes Added PSACR and PRACS processes, modified fallspeed code
 !        2020-10 : M.Leutbecher & S. Lang SPP abstraction and revision
 !        2021-10 : R.Forbes Removed warm autoconv to snow, turned on PSACR to allow frz drz
+!        2023-02 : T.Becker changes for cloud edge erosion:
+!                           calculate saturation deficit wrt env. RH rather than domain mean RH
+!                           assume fixed effective cloud spacing rather than fixed effective cloud scale
+!        2023-02 : T.Becker changes for rain and snow evaporation:
+!                           remove RH-dependent threshold for rain and snow evaporation by setting ZZRH=1
+!                           introduce sub-grid RH enhancement scheme, using Tiedtke (1993) top-hat assumption 
+!                           precipitation fraction is reduced proportionally when rain evaporates
+!                           add factors RXRAINEVAP and RXSNOWSUBL that control rate of rain/snow evaporation
 !
 !     REFERENCES.
 !     ----------
@@ -347,7 +355,7 @@ REAL(KIND=JPRB) :: ZQE
 REAL(KIND=JPRB) :: ZQTMST, ZRDCP
 REAL(KIND=JPRB) :: ZRHC, ZSIG, ZSIGK
 REAL(KIND=JPRB) :: ZWTOT
-REAL(KIND=JPRB) :: ZZCO, ZZRH, ZQADJ
+REAL(KIND=JPRB) :: ZZCO, ZZRH, ZQADJ,ZHLFWDTH
 REAL(KIND=JPRB) :: ZTNEW
 REAL(KIND=JPRB) :: ZRG_R,ZGDPH_R,ZCONS1
 REAL(KIND=JPRB) :: ZLFINAL
@@ -613,6 +621,7 @@ ASSOCIATE(LAERICEAUTO=>YDECLDP%LAERICEAUTO, LAERICESED=>YDECLDP%LAERICESED, &
  & NSSOPT=>YDECLDP%NSSOPT, RAMID=>YDECLDP%RAMID, RAMIN=>YDECLDP%RAMIN, &
  & RCCN=>YDECLDP%RCCN, RCLCRIT_LAND=>YDECLDP%RCLCRIT_LAND, &
  & RCLCRIT_SEA=>YDECLDP%RCLCRIT_SEA, RCLDIFF=>YDECLDP%RCLDIFF, &
+ & RXRAINEVAP=>YDECLDP%RXRAINEVAP, RXSNOWSUBL=>YDECLDP%RXSNOWSUBL, &
  & RCLDIFF_CONVI=>YDECLDP%RCLDIFF_CONVI, RCLDTOPCF=>YDECLDP%RCLDTOPCF, &
  & RCL_APB1=>YDECLDP%RCL_APB1, RCL_APB2=>YDECLDP%RCL_APB2, &
  & RCL_APB3=>YDECLDP%RCL_APB3, RCL_CDENOM1=>YDECLDP%RCL_CDENOM1, &
@@ -1581,11 +1590,18 @@ DO JK=NCLDTOP,KLEV
     ! If cloud liquid water is present
     IF (ZQX(JL,JK,NCLDQL) > ZEPSEC) THEN
 
+      ! Calculate environmental humidity
+      ZQE=(ZQX(JL,JK,NCLDQV)-ZA(JL,JK)*ZQSLIQ(JL,JK))/ &
+    &      MAX(ZEPSEC,1.0_JPRB-ZA(JL,JK))
+
       ! Calculate saturation deficit (wrt water)
-      ZE = MAX(ZQSLIQ(JL,JK)-ZQX(JL,JK,NCLDQV),0.0_JPRB)
+      !ZE = MAX(ZQSLIQ(JL,JK)-ZQX(JL,JK,NCLDQV),0.0_JPRB)
+      ZE = MAX(ZQSLIQ(JL,JK)-ZQE,0.0_JPRB)
 
-      ! Following Morcrette (2012)
-      ZLEROS = 0.333_JPRB * ZA(JL,JK)*(1._JPRB-ZA(JL,JK))*ZLDIFDT(JL)*ZE
+      ! Following Morcrette (2012) 
+      !ZLEROS = 0.333_JPRB * ZA(JL,JK)*(1._JPRB-ZA(JL,JK))*ZLDIFDT(JL)*ZE
+      ! assume fixed effective cloud spacing rather than fixed effective cloud scale
+      ZLEROS = 0.5_JPRB * 0.333_JPRB * SQRT( ZA(JL,JK)*(1._JPRB-ZA(JL,JK)) )*ZLDIFDT(JL)*ZE
       
       ! Limiter taking account of evaporative cooling reducing saturation
       ZLEROS = MIN(ZLEROS,ZEVAPLIMLIQ(JL))
@@ -1615,11 +1631,18 @@ DO JK=NCLDTOP,KLEV
     ! If cloud ice is present
     IF (ZQX(JL,JK,NCLDQI) > ZEPSEC) THEN
 
+      ! Calculate environmental humidity
+      ZQE=(ZQX(JL,JK,NCLDQV)-ZA(JL,JK)*ZQSICE(JL,JK))/ &
+    &      MAX(ZEPSEC,1.0_JPRB-ZA(JL,JK))
+
       ! Calculate saturation deficit (wrt water)
-      ZE = MAX(ZQSICE(JL,JK)-ZQX(JL,JK,NCLDQV),0.0_JPRB)
+      !ZE = MAX(ZQSICE(JL,JK)-ZQX(JL,JK,NCLDQV),0.0_JPRB)
+      ZE = MAX(ZQSICE(JL,JK)-ZQE,0.0_JPRB)
 
       ! Following Morcrette (2012)
-      ZLEROS = 0.333_JPRB * ZA(JL,JK)*(1._JPRB-ZA(JL,JK))*ZLDIFDT(JL)*ZE
+!      ZLEROS = 0.333_JPRB * ZA(JL,JK)*(1._JPRB-ZA(JL,JK))*ZLDIFDT(JL)*ZE
+      ! assume fixed effective cloud spacing rather than fixed effective cloud scale
+      ZLEROS = 0.5_JPRB * 0.333_JPRB * SQRT( ZA(JL,JK)*(1._JPRB-ZA(JL,JK)) )*ZLDIFDT(JL)*ZE
       
       ! Limiter taking account of evaporative cooling reducing saturation
       ZLEROS = MIN(ZLEROS,ZEVAPLIMICE(JL))
@@ -1682,10 +1705,10 @@ DO JK=NCLDTOP,KLEV
 
   ENDDO
 
-  ! Turbulent erosion of liquid
+  ! Turbulent erosion of liquid and ice together
   DO JL=KIDIA,KFDIA
 
-    ! If cloud liquid water is present
+    ! If cloud liquid water or ice is present
     IF(ZLI(JL,JK) > ZEPSEC) THEN
 
       ! Calculate environmental humidity
@@ -1696,8 +1719,11 @@ DO JK=NCLDTOP,KLEV
       ZE = MAX(ZQSMIX(JL,JK)-ZQE,0.0_JPRB)
             
       ! Following Morcrette (2012)
-      ZLEROS = 0.333_JPRB * ZA(JL,JK)*(1._JPRB-ZA(JL,JK))*ZLDIFDT(JL)*ZE
-      
+      !ZLEROS = 0.333_JPRB * ZA(JL,JK)*(1._JPRB-ZA(JL,JK))*ZLDIFDT(JL)*ZE
+      ! assume fixed effective cloud spacing rather than fixed effective cloud scale
+      ZLEROS = 0.5_JPRB * 0.333_JPRB * SQRT( ZA(JL,JK)*(1._JPRB-ZA(JL,JK)) )*ZLDIFDT(JL)*ZE
+
+
       ! Limiter taking account of evaporative cooling reducing saturation
       ZLEROS = MIN(ZLEROS,ZEVAPLIMMIX(JL))
       
@@ -1764,7 +1790,7 @@ DO JK=NCLDTOP,KLEV
     !-----------
     ! if aerosol effect then override 
     !  note that for T>233K this is the same as above.
-    IF (LAERICESED .AND. JM == NCLDQI) THEN
+    IF (LAERICESED) THEN
       ZRE_ICE=PRE_ICE(JL,JK) 
       ! The exponent value is from 
       ! Morrison et al. JAS 2005 Appendix
@@ -2256,6 +2282,20 @@ DO JK=NCLDTOP,KLEV
     ! Limit further to not go above 90%
     ZZRH = MIN(0.9_JPRB,ZZRH)
 
+  ! start evaporating the hydrometeors immediately when RH<100%
+    ZZRH = 1.0_JPRB
+
+  ! Calculate environmental humidity
+    ZQE=(ZQX(JL,JK,NCLDQV)-ZA(JL,JK)*ZQSLIQ(JL,JK))/ &
+    &    MAX(ZEPSEC,1.0_JPRB-ZA(JL,JK))
+
+  ! If subgrid heterogeneity assumption, then subgrid precip sees most
+  ! humid part of the grid box. Assume top-hat pdf as Tiedtke (1993)
+  ! Calculate half-width of subgrid humidity distribution ZHLFWDTH
+  ! ZRHC=RAMID=0.8
+
+    ZHLFWDTH   = MIN(MIN(1.0_JPRB-ZQE/ZQSLIQ(JL,JK),ZQE/ZQSLIQ(JL,JK)),1.0_JPRB-ZRHC)
+
   
     ZQE=MAX(0.0_JPRB,MIN(ZQX(JL,JK,NCLDQV),ZQSLIQ(JL,JK)))
 
@@ -2289,9 +2329,14 @@ DO JK=NCLDTOP,KLEV
       ZCORR2= (ZTP1(JL,JK)/273._JPRB)**1.5_JPRB*393._JPRB/(ZTP1(JL,JK)+120._JPRB)
       ZKA = RCL_KA273*ZCORR2
 
-      ZSUBSAT = MAX(ZZRH*ZQSLIQ(JL,JK)-ZQE,0.0_JPRB)
+      ! Calculate mean subsaturation of precipitating fraction of the gridbox
+      ! ZSUBSAT = MAX(ZZRH*ZQSLIQ(JL,JK)-ZQE,0.0_JPRB)      
+      ! IMPORTANT NOTE: ZZRH should possibly be taken out of the equation 
+      ! to make it consistent with ice evaporation but does not matter as long as ZZRH is set to 1
+      ZSUBSAT = ZQSLIQ(JL,JK) * MAX(ZZRH*1.0_JPRB-(ZQE/ZQSLIQ(JL,JK) &
+                & +(1.0_JPRB-ZCOVPCLR(JL)/MAX(ZEPSEC,1.0_JPRB-ZA(JL,JK)))*ZHLFWDTH),0.0_JPRB)
 
-      ZBETA = (0.15_JPRB/ZQSLIQ(JL,JK))*ZTP1(JL,JK)**2._JPRB*ZESATLIQ* &
+      ZBETA = (RXRAINEVAP/ZQSLIQ(JL,JK))*ZTP1(JL,JK)**2._JPRB*ZESATLIQ* &
      & RCL_CONST1R*(ZCORR2/ZEVAP_DENOM)*(0.78_JPRB/(ZLAMBDA**RCL_CONST4R)+ &
      & RCL_CONST2R*(ZRHO(JL)*ZFALLCORR)**0.5_JPRB/ &
      & (ZCORR2**0.5_JPRB*ZLAMBDA**RCL_CONST3R))
@@ -2324,10 +2369,11 @@ DO JK=NCLDTOP,KLEV
       ! to mimic the previous scheme which had a diagnostic
       ! 2-flux treatment, abandoned due to the new prognostic precip
       !-------------------------------------------------------------
-      ! Comment out reduction of precipitation fraction with evaporation 
-      !ZCOVPTOT(JL) = MAX(RCOVPMIN,ZCOVPTOT(JL)-MAX(0.0_JPRB, &
-      ! &            (ZCOVPTOT(JL)-ZA(JL,JK))*ZEVAP/ZQXFG(JL,NCLDQR)))
-
+      IF(ZQXFG(JL,NCLDQR)>ZEPSEC) THEN
+      ZCOVPTOT(JL) = MAX(RCOVPMIN,ZCOVPTOT(JL)-MAX(0.0_JPRB, &
+     &              (ZCOVPTOT(JL)-ZA(JL,JK))*ZEVAP/(ZQXFG(JL,NCLDQR)+ZQXFG(JL,NCLDQS))))
+      ENDIF
+      
       ! Update fg field 
       ZQXFG(JL,NCLDQR) = ZQXFG(JL,NCLDQR)-ZEVAP
     
@@ -2863,8 +2909,7 @@ DO JK=NCLDTOP,KLEV
 
           ! Calculate freezing rate based on Bigg(1953) and Wisner(1972)
           ZTEMP = MIN(RCL_FZRAB*(ZTP1(JL,JK)-RTT), 50._JPRB) ! for EXP security
-          ZFRZ  = PTSPHY * (RCL_CONST5R/ZRHO(JL)) * (EXP(ZTEMP)-1._JPRB) &
-                  & * ZLAMBDA**RCL_CONST6R
+          ZFRZ  = PTSPHY * (RCL_CONST5R/ZRHO(JL) * ZLAMBDA**RCL_CONST6R) * (EXP(ZTEMP)-1._JPRB)
           ZFRZMAX(JL) = MAX(ZFRZ,0.0_JPRB)
 
         ELSE
@@ -3211,9 +3256,21 @@ DO JK=NCLDTOP,KLEV
   DO JL=KIDIA,KFDIA
     ZZRH=RPRECRHMAX+(1.0_JPRB-RPRECRHMAX)*ZCOVPMAX(JL)/MAX(ZEPSEC,1.0_JPRB-ZA(JL,JK))
     ZZRH=MIN(MAX(ZZRH,RPRECRHMAX),1.0_JPRB)
+
+    ! start evaporating the hydrometeors immediately when RH<100%
+    ZZRH = 1.0_JPRB
+
+  ! Calculate environmental humidity
     ZQE=(ZQX(JL,JK,NCLDQV)-ZA(JL,JK)*ZQSICE(JL,JK))/ &
     & MAX(ZEPSEC,1.0_JPRB-ZA(JL,JK))  
 
+  ! If subgrid heterogeneity assumption, then subgrid precip sees most
+  ! humid part of the grid box. Assume top-hat pdf as Tiedtke (1993)
+  ! Calculate half-width of subgrid humidity distribution ZHLFWDTH
+  ! ZRHC=RAMID=0.8
+
+    ZHLFWDTH   = MIN(MIN(1.0_JPRB-ZQE/ZQSICE(JL,JK),ZQE/ZQSICE(JL,JK)),1.0_JPRB-ZRHC)
+
     !---------------------------------------------
     ! humidity in moistest ZCOVPCLR part of domain
     !---------------------------------------------
@@ -3235,10 +3292,14 @@ DO JK=NCLDTOP,KLEV
        & PAPH(JL,KLEV+1))/RVRFACTOR*ZPRECLR/ &
        & MAX(ZCOVPCLR(JL),ZEPSEC)
 
-      ZBETA=RG*RPECONS*(ZBETA1)**0.5777_JPRB  
+      ZBETA=RXSNOWSUBL*RG*RPECONS*(ZBETA1)**0.5777_JPRB  
+
+     ! Calculate mean subsaturation of precipitating fraction of the gridbox
+      ZSUBSAT = ZQSICE(JL,JK) * MAX( 1.0_JPRB-(ZQE/ZQSICE(JL,JK)+ &
+                & (1.0_JPRB-ZCOVPCLR(JL)/MAX(ZEPSEC,1.0_JPRB-ZA(JL,JK)))*ZHLFWDTH),0.0_JPRB) 
 
       ZDENOM=1.0_JPRB+ZBETA*PTSPHY*ZCORQSICE(JL)
-      ZDPR = ZCOVPCLR(JL)*ZBETA*(ZQSICE(JL,JK)-ZQE)/ZDENOM*ZDP(JL)*ZRG_R
+      ZDPR = ZCOVPCLR(JL)*ZBETA*ZSUBSAT/ZDENOM*ZDP(JL)*ZRG_R
       ZDPEVAP=ZDPR*ZDTGDP(JL)
 
       !Apply SPP perturbations
@@ -3266,8 +3327,8 @@ DO JK=NCLDTOP,KLEV
       ! 2-flux treatment, abandoned due to the new prognostic precip
       !-------------------------------------------------------------
       ZCOVPTOT(JL) = MAX(RCOVPMIN,ZCOVPTOT(JL)-MAX(0.0_JPRB, &
-     &              (ZCOVPTOT(JL)-ZA(JL,JK))*ZEVAP/ZQXFG(JL,NCLDQS)))
-      
+     &              (ZCOVPTOT(JL)-ZA(JL,JK))*ZEVAP/(ZQXFG(JL,NCLDQR)+ZQXFG(JL,NCLDQS))))
+
       !Update first guess field
       ZQXFG(JL,NCLDQS) = ZQXFG(JL,NCLDQS)-ZEVAP
 
@@ -3286,6 +3347,9 @@ DO JK=NCLDTOP,KLEV
     ZZRH=RPRECRHMAX+(1.0_JPRB-RPRECRHMAX)*ZCOVPMAX(JL)/MAX(ZEPSEC,1.0_JPRB-ZA(JL,JK))
     ZZRH=MIN(MAX(ZZRH,RPRECRHMAX),1.0_JPRB)
 
+    ! start evaporating the hydrometeors immediately when RH<100%
+    ZZRH = 1.0_JPRB
+
     ZQE=(ZQX(JL,JK,NCLDQV)-ZA(JL,JK)*ZQSICE(JL,JK))/ &
     & MAX(ZEPSEC,1.0_JPRB-ZA(JL,JK))  
      
@@ -3325,7 +3389,7 @@ DO JK=NCLDTOP,KLEV
       ZTERM2 = 0.65*RCL_CONST6S*ZPR02**RCL_CONST4S+RCL_CONST3S*ZCORRFAC**0.5 &
      &          *ZRHO(JL)**0.5*ZPR02**RCL_CONST5S/ZCORRFAC2**0.5
 
-      ZDPEVAP = MAX(ZCOVPCLR(JL)*ZTERM1*ZTERM2*PTSPHY,0.0_JPRB)
+      ZDPEVAP = RXSNOWSUBL*MAX(ZCOVPCLR(JL)*ZTERM1*ZTERM2*PTSPHY,0.0_JPRB)
  
       !--------------------------------------------------------------------
       ! Limit evaporation to snow amount
